@@ -14,7 +14,7 @@
  * 
  */
 
-/* Mail comments or questions to ytalk@austin.eds.com */
+/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 #include "socket.h"
@@ -621,6 +621,7 @@ connect_user(fd)
   int fd;
 {
     register yuser *user, *u;
+    unsigned int major, minor, patch;
 
     if((user = fd_to_user[fd]) == NULL)
     {
@@ -647,8 +648,10 @@ connect_user(fd)
     {
 	(void)memset(&parm, 0, sizeof(y_parm));
 	parm.protocol = YTP_NEW;
-	parm.vmajor = htons(VMAJOR);
-	parm.vminor = htons(VMINOR);
+	/* Get the version number */
+	sscanf(PACKAGE_VERSION, "%u.%u.%u", &major, &minor, &patch);
+	parm.vmajor = htons(major);
+	parm.vminor = htons(minor);
 	parm.rows = htons(me->t_rows);
 	parm.cols = htons(me->t_cols);
 	parm.my_rows = htons(user->t_rows);
@@ -865,7 +868,8 @@ invite(name, send_announce)
     if (!dont_change_my_addr)
     {
     	struct sockaddr_in tmpsock;
-	int sock, i;
+	int sock;
+	unsigned int i;
 
 	sock = socket(PF_INET, SOCK_DGRAM, 0);
 
