@@ -14,7 +14,7 @@
  * 
  */
 
-/* Mail comments or questions to ytalk@austin.eds.com */
+/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 
@@ -244,6 +244,19 @@ execute(command)
     if((shell = (char *)getenv("SHELL")) == NULL)
 	shell = "/bin/sh";
     calculate_size(&prows, &pcols);
+#if defined(SIGCHLD)
+    /* 
+       Modified by P. Maragakis (Maragakis@mpq.mpg.de) Aug 10, 1999,
+       following hints by Jason Gunthorpe.  
+       This closes two debian bugs (#42625, #2196).
+    */
+    signal(SIGCHLD, SIG_DFL);
+#else
+# if defined(SIGCLD)
+    signal(SIGCLD, SIG_DFL);
+# endif
+#endif
+    /* End of modification */
     if((pid = fork()) == 0)
     {
 	close(fd);
@@ -291,6 +304,16 @@ execute(command)
 	perror("execl");
 	(void)exit(-1);
     }
+    /* Modified by P. Maragakis (Maragakis@mpq.mpg.de) Aug 10, 1999. */
+#if defined(SIGCHLD)
+    signal(SIGCHLD, SIG_IGN);
+#else
+# if defined(SIGCLD)
+    signal(SIGCLD, SIG_IGN);
+# endif
+#endif
+    /* End of modification */
+
     if(pid < 0)
     {
 	show_error("fork() failed");
