@@ -14,7 +14,7 @@
  * 
  */
 
-/* Mail comments or questions to ytalk@austin.eds.com */
+/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 #include "menu.h"
@@ -310,3 +310,19 @@ input_loop()
     input_flag = 0;
     left_loop = 1;
 }
+
+/* Wait for a character from the terminal, in preparation for bailing out;
+ * then read and discard that keypress.
+ */
+void
+bail_loop()
+{
+    fd_set stdin_set;
+    char keypress[1];
+
+    FD_ZERO(&stdin_set);
+    FD_SET(0, &stdin_set);
+    select(1, &stdin_set, 0, 0, NULL);
+    full_read(0, keypress, 1);
+}
+
