@@ -14,9 +14,7 @@
  * 
  */
 
-/* Mail comments or questions to ytalk@austin.eds.com */
-
-#include "config.h"
+/* Mail comments or questions to metawire.org */
 
 #ifndef X_DISPLAY_MISSING
 # define USE_X11
@@ -31,6 +29,14 @@
 #include <string.h>
 #include <stdio.h>
 
+/* If grantpt/unlockpt/ptsname are available we still haven't got
+   prototypes. So we fix this here.                               */
+#if defined(HAVE_PTSNAME) && defined(HAVE_GRANTPT) && defined(HAVE_UNLOCKPT)
+extern int grantpt (int __fd);
+extern int unlockpt (int __fd);
+extern char *ptsname (int __fd);
+#endif
+
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
@@ -39,10 +45,6 @@
 # include <X11/X.h>
 #endif
 
-#define VMAJOR	3	/* major version number */
-#define VMINOR	1	/* minor version number */
-#define VPATCH	1	/* patch level */
-
 #define EIGHT_BIT_CLEAN /* take this one out if you don't want it */
 
 #ifdef EIGHT_BIT_CLEAN
@@ -130,7 +132,12 @@ typedef struct _yuser {
     void (*dfunc)();		/* function to call with drained data */
     int got_oob;		/* got OOB flag */
 
-    /* anything below this is available for the terminal interface */
+#define DUMP_BUF_SIZE 4095
+    char dump_buf[DUMP_BUF_SIZE+1];
+    int dump_buf_len;
+    
+
+      /* anything below this is available for the terminal interface */
 
     yterm term;			/* terminal cookie */
     int ty, tx;			/* terminal's idea of Y,X (optional) */
@@ -150,6 +157,7 @@ typedef struct _yuser {
 #define FL_CAPS		0x00000100L     /* want caps as answers */
 #define FL_NOAUTO       0x00000200L     /* no auto-invite port */
 #define FL_PROMPTRING	0x00000400L	/* prompt before reringing */
+#define FL_PROMPTQUIT	0x00000800L     /* prompt before quitting */
 #define FL_LOCKED	0x40000000L	/* flags locked by other end */
 
 /* ---- defines and short-cuts ---- */
@@ -234,6 +242,7 @@ typedef struct {
 
 /* ---- exit codes ---- */
 
+#define YTE_SUCCESS_PROMPT -1	/* successful completion, prompt, return 0 */
 #define YTE_SUCCESS	0	/* successful completion */
 #define YTE_INIT	1	/* initialization error */
 #define YTE_NO_MEM	2	/* out of memory */
@@ -334,6 +343,7 @@ extern void	remove_fd	( /* fd */ );			/* fd.c */
 extern int	full_read	( /* fd, buf, len */ );		/* fd.c */
 extern void	main_loop	();				/* fd.c */
 extern void	input_loop	();				/* fd.c */
+extern void	bail_loop	();				/* fd.c */
 
 extern yuser   *invite		( /* username, announce */ );	/* comm.c */
 extern void	house_clean	();				/* comm.c */
@@ -365,4 +375,9 @@ extern void	update_exec	();				/* exec.c */
 extern void	kill_exec	();				/* exec.c */
 extern void	winch_exec	();				/* exec.c */
 
+extern void	set_file_dump	(char *fn);			/* log.c */
+extern void	addch_dump	(yuser *user, ychar c);		/* log.c */
+extern void	rub_dump	(yuser *user);			/* log.c */
+extern void	newline_dump	(yuser *user);			/* log.c */
+
 /* EOF */
