@@ -14,12 +14,19 @@
  * 
  */
 
-/* Mail comments or questions to ytalk@austin.eds.com */
+/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 #include <signal.h>
 #include "menu.h"
 
+
+#ifndef HAVE_GETOPT_LONG
+#include "getopt.h"
+#else
+#include <getopt.h>
+#endif
+
 char errstr[132];	/* temporary string for errors */
 char *vhost = NULL;	/* specified virtual host */
 
@@ -29,9 +36,15 @@ void
 bail(n)
   int n;
 {
-    end_term();
     kill_auto();
-    (void)exit(n);
+    if(n == YTE_SUCCESS_PROMPT && (def_flags & FL_PROMPTQUIT))
+       if(show_mesg("Press any key to quit.", NULL) == 0)
+       {
+           update_menu();
+           bail_loop();
+       }
+    end_term();
+    (void)exit(n == YTE_SUCCESS_PROMPT ? YTE_SUCCESS : n);
 }
 
 #ifndef HAVE_STRERROR
@@ -129,7 +142,7 @@ got_sig(n)
   int n;
 {
     if(n == SIGINT)
-	bail(0);
+	bail(YTE_SUCCESS);
     bail(YTE_SIGNAL);
 }
 
@@ -139,8 +152,35 @@ main(argc, argv)
   int argc;
   char **argv;
 {
-    int xflg = 0, sflg = 0, yflg = 0, iflg = 0;
-    char *prog;
+    int xflg = 0, sflg = 0, yflg = 0, iflg = 0, qflg = 0;
+    int optchar;
+    struct option longopts[] = {
+	#ifdef USE_X11
+	{"x-interface",		0, 0, 'x'},
+	#endif
+	{"no-auto-invite-port",	0, 0, 'i'},
+	{"require-caps",	0, 0, 'Y'},
+	{"start-shell",		0, 0, 's'},
+	{"quit-prompt",		0, 0, 'q'},
+	{"virtual-host",	1, 0, 'h'},
+	{"dump",		1, 0, 'd'},
+	{0, 0, 0, 0}
+    }, *optsptr;
+    struct optiondesc {
+	const char *arg;
+	const char *desc;
+    } longopts_desc[] = {
+	#ifdef USE_X11
+	{NULL, "use the X interface"},
+	#endif
+	{NULL, "no auto-invite port"},
+	{NULL, "require caps on all y/n answers"},
+	{NULL, "start a shell"},
+	{NULL, "prompt before quitting"},
+	{"host_or_ip", "select interface or virtual host"},
+	{"filename", "enable, and select file to, dump"},
+	{NULL, NULL}
+    }, *descsptr;
 
     /* check for a 64-bit mis-compile */
 
@@ -153,53 +193,43 @@ then type 'make clean' and 'make'.\n");
     }
 
     /* search for options */
-
-    prog = *argv;
-    argv++, argc--;
-    while(argc > 0 && **argv == '-')
+    while((optchar = getopt_long(argc, argv,
+    #ifdef USE_X11
+    "x"
+    #endif
+                                 "iYsh:d:", longopts, NULL)) != -1)
+    	switch(optchar)
     {
-	if(strcmp(*argv, "-x") == 0
-	|| strcmp(*argv, "-nw") == 0)
-	{
-	    xflg++;	/* disable X from the command line */
-	    argv++, argc--;
-	}
-	else if(strcmp(*argv, "-Y") == 0)
-	{
-	    yflg++;
-	    argv++, argc--;
-	}
-	else if(strcmp(*argv, "-i") == 0)
-	{
-	    iflg++;
-	    argv++, argc--;
-	}
-	else if (strcmp(*argv, "-h") == 0)
-        {
-            argv++;
-            vhost = *argv++;
- 	    argc -= 2;
-        }
-	else if(strcmp(*argv, "-s") == 0)
-	{
-	    sflg++;	/* immediately start a shell */
-	    argv++, argc--;
-	}
-	else
-	    argc = 0;	/* force a Usage error */
+	#ifdef USE_X11
+	case 'x': xflg++; break;
+	#endif
+	case 'i': iflg++; break;
+	case 'Y': yflg++; break;		
+	case 's': sflg++; break;
+	case 'q': qflg++; break;
+	case 'h': vhost = optarg; break;
+	case 'd': set_file_dump(optarg); break;
+	case '?': argc = 0; break;		/* force usage error */
     }
 
     /* check for users */
-
-    if(argc <= 0)
+    if(argc <= optind)
     {
-	fprintf(stderr, 
-"Usage:    %s [options] user[@host][#tty]...\n\
-Options:     -i             --    no auto-invite port\n\
-             -x             --    do not use the X interface\n\
-             -Y             --    require caps on all y/n answers\n\
-             -s             --    start a shell\n\
-             -h host_or_ip  --    select interface or virtual host\n", prog);
+	fprintf(stderr, "Usage:    %s [options] user[@host][#tty]...\n",
+	        argv[0]);
+	optsptr = longopts;
+	descsptr = longopts_desc;
+	while(optsptr->name)
+	{
+	    fprintf(stderr,"    -%c or --%-15s %-*s --   %s\n",
+	            optsptr->val, optsptr->name,
+		    strlen(optsptr->name) > 15 ?
+		      11 - (strlen(optsptr->name) - 15) : 11,
+		    descsptr->arg ? descsptr->arg : "",
+	            descsptr->desc);
+	    ++ optsptr;
+	    ++ descsptr;
+	}
 	(void)exit(YTE_INIT);
     }
 
@@ -213,7 +243,7 @@ Options:     -i             --    no auto-invite port\n\
 
     /* set default options */
 
-    def_flags = FL_XWIN | FL_PROMPTRING | FL_RING;
+    def_flags = FL_PROMPTRING | FL_RING | FL_SCROLL;
 
     /* go for it! */
 
@@ -222,16 +252,18 @@ Options:     -i             --    no auto-invite port\n\
     read_ytalkrc();
     init_user(vhost);
     if(xflg)
-	def_flags &= ~FL_XWIN;
+	def_flags |= FL_XWIN;
     if(yflg)
 	def_flags |= FL_CAPS;
     if(iflg)
 	def_flags |= FL_NOAUTO;
+    if (qflg)
+        def_flags |= FL_PROMPTQUIT;
 
     init_term();
     init_socket();
-    for(; argc > 0; argc--, argv++)
-	invite(*argv, 1);
+    for(; optind < argc; optind ++)
+	invite(argv[optind], 1);
     if(sflg)
 	execute(NULL);
     else
