@@ -14,7 +14,7 @@
  * 
  */
 
-/* Mail comments or questions to ytalk@austin.eds.com */
+/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 
@@ -92,12 +92,11 @@ static menu_item error_menu[] = {
 /* ---- local functions ---- */
 
 static yuser *output_user = NULL;
-
-static void
-do_output(filename)
-  char *filename;
+/*Output Function*/
+static void do_output(filename)
+char *filename;
 {
-    int fd;
+int fd;
 
     if(output_user == NULL)
 	return;
@@ -110,9 +109,8 @@ do_output(filename)
     spew_term(output_user, fd, output_user->rows, output_user->cols);
     output_user = NULL;
 }
-
-static void
-do_output_user(user)
+/*Output User Function */
+static void do_output_user(user)
   yuser *user;
 {
     /* if he has an open descriptor, close it */
@@ -134,22 +132,16 @@ do_output_user(user)
     else
 	output_user = NULL;
 }
-
-static void
-do_invite(name)
-  char *name;
-{
-    invite(name, 1);
+/*Invite User Function*/
+static void do_invite(name){
+ invite(name, 1);
 }
-
-static void
-kill_all_unconnected()
-{
-    while(wait_list) free_user(wait_list);
+/*Kill All Conenctions*/
+static void kill_all_unconnected(){
+  while(wait_list) free_user(wait_list);
 }
-
-static void
-main_menu_sel(key)
+/*Menu Selection Function*/
+static void main_menu_sel(key)
   ychar key;
 {
     switch(key)
@@ -183,12 +175,11 @@ main_menu_sel(key)
 		update_menu();
 	    break;
 	case 'q':	/* quit */
-	    bail(0);
+	    bail(YTE_SUCCESS);
     }
 }
-
-static void
-option_menu_sel(key)
+/*Option  Menu Selection Function*/
+static void option_menu_sel(key)
   ychar key;
 {
     register yuser *u;
@@ -218,6 +209,9 @@ option_menu_sel(key)
 	case 'p':	/* toggle prompting before re-rings */
 	    def_flags ^= FL_PROMPTRING;
 	    break;
+	case 'q':       /* toggle prompting before quitting */
+	   def_flags ^= FL_PROMPTQUIT;
+	   break;
     }
 
     if(old_flags != def_flags)
@@ -233,8 +227,8 @@ option_menu_sel(key)
 	kill_menu();
 }
 
-static void
-user_menu_sel(key)
+/*User Menu Selection Function*/
+static void user_menu_sel(key)
   ychar key;
 {
     register int i;
@@ -262,22 +256,18 @@ user_menu_sel(key)
 
 #define MENU_EXTRA 7	/* number of extra characters per menu screen item */
 
-static void
-generate_text_length()
-{
+/*Generate Text Length*/
+static void generate_text_length(){
     menu_long = me->t_cols - MENU_EXTRA - 2;
     if(menu_long < 5 || menu_long > MAXTEXT)
 	menu_long = MAXTEXT;
 }
 
-static void
-generate_yes_no_length()
-{
+/*Yes/No Length*/
+static void generate_yes_no_length(){
     menu_long = strlen(yes_no_menu[0].item) - 2;
 }
-
-static void
-pad_str(from, len, to)
+static void pad_str(from, len, to)
   char *from, *to;
   int len;
 {
@@ -292,9 +282,7 @@ pad_str(from, len, to)
 
 /* End any menu processing.
  */
-void
-kill_menu()
-{
+void kill_menu(){
     register int i;
 
     if(menu_ptr != NULL)
@@ -745,6 +733,14 @@ show_option_menu()
     option_menu[i].key = 'p';
     i++;
 
+    if(def_flags & FL_PROMPTQUIT)
+	option_menu[i].item = "don't prompt before quitting";
+    else
+	option_menu[i].item = "prompt before quitting";
+    option_menu[i].func = option_menu_sel;
+    option_menu[i].key = 'q';
+    i++;
+
     if(term_does_asides())
     {
 	if(def_flags & FL_ASIDE)
