@@ -14,7 +14,7 @@
  * 
  */
 
-/* Mail comments or questions to ytalk@austin.eds.com */
+/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 
@@ -179,12 +179,12 @@ init_term()
 
     /* set me up a terminal */
 
-    sprintf(tmpstr, "YTalk version %d.%d.%d", VMAJOR, VMINOR, VPATCH);
+    sprintf(tmpstr, "YTalk version %s", PACKAGE_VERSION);
     if(open_term(me, tmpstr) < 0)
     {
 	end_term();
 	show_error("init_term: open_term() failed");
-	bail(0);
+	bail(YTE_SUCCESS);
     }
 }
 
@@ -290,6 +290,7 @@ addch_term(user, c)
 {
     if (is_printable(c))
     {
+        addch_dump(user,c);
 	_addch_term(user, c);
 	user->scr[user->y][user->x] = c;
 	if(++(user->x) >= user->cols)
@@ -489,7 +490,7 @@ rub_term(user)
 	    addch_term(user, ' ');
 	    move_term(user, user->y, user->x - 1);
 	}
-
+       rub_dump(user);
     }
 }
 
@@ -542,6 +543,7 @@ newline_term(user)
   register yuser *user;
 {
     register int new_y, next_y;
+    newline_dump(user);
 
     new_y = user->y + 1;
     if(user->flags & FL_RAW)
@@ -737,6 +739,8 @@ del_char_term(user, num)
     register ychar *c;
     register int i;
 
+    printf("num=%d\n",num);
+
     /* find number of remaining non-blank chars */
 
     i = user->cols - user->x - num;
