@@ -14,12 +14,13 @@
  * 
  */
 
-/* Mail comments or questions to ytalk@austin.eds.com */
+/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 #include "menu.h"
 #include <pwd.h>
 #include <string.h>
+#include <netdb.h>
 
 extern char *getlogin();
 extern int dont_change_my_addr;
@@ -126,6 +127,7 @@ char *vhost;
     int my_uid;
     char *my_name, *my_vhost;
     char my_host[100];
+    unsigned int major, minor, patch;
 
     user_list = NULL;
     connect_list = NULL;
@@ -186,8 +188,12 @@ char *vhost;
 	bail(YTE_ERROR);
     me->key = '@';
     me->remote.protocol = YTP_NEW;
-    me->remote.vmajor = VMAJOR;
-    me->remote.vminor = VMINOR;
+
+    /* Get the version number */
+    sscanf(PACKAGE_VERSION, "%u.%u.%u", &major, &minor, &patch);
+    
+    me->remote.vmajor = major;
+    me->remote.vminor = minor;
     me->remote.pid = getpid();
 
     close_passwd();
@@ -298,7 +304,7 @@ free_user(user)
         && wait_list == NULL
         && menu_ptr == NULL
         && running_process == 0)
-            bail(0);
+            bail(YTE_SUCCESS_PROMPT);
 
     close_term(user);
     free(user->full_name);
